=================
AWS Batch Helpers
=================


.. image:: https://img.shields.io/pypi/v/aws_batch_helpers.svg
        :target: https://pypi.python.org/pypi/aws_batch_helpers

.. image:: https://img.shields.io/travis/biohub/aws_batch_helpers.svg
        :target: https://travis-ci.com/biohub/aws_batch_helpers

.. image:: https://readthedocs.org/projects/aws-batch-helpers/badge/?version=latest
        :target: https://aws-batch-helpers.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/biohub/aws_batch_helpers/shield.svg
     :target: https://pyup.io/repos/github/biohub/aws_batch_helpers/
     :alt: Updates



Helpers for running jobs on AWS Batch


* Free software: MIT license
* Documentation: https://aws-batch-helpers.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
